@@ -1,7 +1,7 @@
 #' @title Visualise a section in data space
 #'
 #' @description Visualise a section in data space, showing fitted models where
-#'   they intersect the section, and nearby observations. The similarity weight for
+#'   they intersect the section, and nearby observations. The \code{weights} for
 #'   observations can be calculated with \code{\link{similarityweight}}. This
 #'   function is mainly for use in \code{\link{ceplot}} and
 #'   \code{\link{condtour}}.
@@ -51,6 +51,8 @@
 #' model <- lm(mpg ~ ., data = mtcars)
 #' plotxs(xs = mtcars[, "wt", drop = FALSE], y = mtcars[, "mpg", drop = FALSE],
 #'   xc.cond = mtcars[1, ], model = list(model))
+#'
+#' @seealso \code{\link{plotxc}}, \code{\link{ceplot}}, \code{\link{condtour}}
 
 plotxs <-
 function (xs, y, xc.cond, model, model.colour = NULL, model.lwd = NULL,
@@ -60,7 +62,7 @@ function (xs, y, xc.cond, model, model.colour = NULL, model.lwd = NULL,
   FALSE)
 {
   ny <- nrow(y)
-  col <- rep(col, ny)
+  col <- rep(col, length.out = ny)
   dev.hold()
 
 ## If no weights are provided, just show all data with the appropriate colour.
@@ -84,7 +86,7 @@ function (xs, y, xc.cond, model, model.colour = NULL, model.lwd = NULL,
 
 ## Organise defaults and check inputs.
 
-  pch <- rep(pch, ny)
+  pch <- rep(pch, length.out = ny)
   if (ncol(y) != 1)
     stop("y must be a dataframe with 1 column")
   model <- if (!is.list(model))
